@@ -59,17 +59,22 @@ def generate(
     echo("""
     Learn more by reading the documentation at: https://gu-charbon.gitbook.io/fastrepo/.
 
-    Do not forget to enable your environment before starting to develop:
+    Do not forget to activate your environment before starting to develop:
 
         $ poetry shell
+    Or:
+        - on linux:
+            $ .venv/bin/activate
+        - on windows:
+            $ .venv/Script/activate.ps1
 
     Once you activated your environment, you can use the following command to list all available tasks:
 
-        $ inv --list
+        $ pydev --help
     Or
-        $ poetry run inv --list
-
-    If you did not activate your environment.
+        $ poetry run pydev --help
+    
+    if you did not activate your environment.
 
     Happy coding!
     """)
